#[repr(usize)]pub enum Retry {
NONE = 1,
ONCE = 2,
TWICE = 3,
}Expand description
Tells the client to execute transaction one more time if it’s failed.
It’s only happens during InvalidNonce error.
- NONE - default value, transaction executes once
- ONCE - retry once
- TWICE - retry two times
Variants
NONE = 1
Executes once, basically no retry
ONCE = 2
If InvalidNonce error received try to execute one more time
TWICE = 3
If InvalidNonce error received try to execute two times