NearClient

Struct NearClient 

pub struct NearClient { /* private fields */ }
Near RPC client

Implementations

Source

impl NearClient

pub fn new(url: Url) -> Result<Self, Error>

Creates a new client

Arguments
  • url - A RPC Endpoint Url
pub async fn block(&self, finality: Finality) -> Result<CryptoHash, Error>

Queries network and returns block for given height or hash

pub async fn view<'a, T: DeserializeOwned>( &'a self, contract_id: &'a AccountId, finality: Finality, method: &'static str, args: Option<Value>, ) -> Result<ViewOutput<T>, Error>

Allows you to call a contract method as a view function.

Arguments

  • contract_id - The AccountId where smart contract is located
  • finality - Finality
  • method - Function that is declared in a smart contract
  • args - Function arguments, could be empty
pub async fn view_access_key( &self, account_id: &AccountId, public_key: &Ed25519PublicKey, finality: Finality, ) -> Result<AccessKeyView, Error>

Returns information about a single access key for given account

Arguments

pub async fn view_access_key_list( &self, account_id: &AccountId, finality: Finality, ) -> Result<AccessKeyListView, Error>

Returns list of all access keys for the given account

Arguments

  • account_id - The user AccountId in a Near network
pub async fn view_contract_state( &self, account_id: &AccountId, ) -> Result<ViewStateResult, Error>

Returns information regarding contract state in a key-value sequence representation

Arguments

  • account_id - The contract AccountId in a Near network
pub async fn network_status(&self) -> Result<StatusResponse, Error>

Returns general status of a given node (sync status, nearcore node version, protocol version, etc), and the current set of validators.

pub async fn view_transaction<'a>( &'a self, transaction_id: &'a CryptoHash, signer: &'a Signer, ) -> Result<Output, Error>

Queries status of a transaction by hash, returning the final transaction result and details of all receipts.

Arguments

Return

If a transaction still processing will be returned an error Error::ViewTransaction, in this case can try to execute view_transaction one more time, or a several times. If an error differs from Error::ViewTransaction that something goes totally wrong and you should stop to try executing view_transaction with the same arguments/signer

pub async fn view_account( &self, account_id: &AccountId, ) -> Result<Account, Error>

Returns basic account information.

Arguments
  • account_id - The account ID AccountId for which to retrieve information.
Returns

Returns a struct Account containing basic information about the specified Near account.

pub fn add_access_key<'a>( &'a self, signer: &'a Signer, account_id: &'a AccountId, new_account_pk: Ed25519PublicKey, permission: AccessKeyPermission, ) -> FunctionCall<'_>

Creates new access key on the specified account

Arguments

  • signer - Transaction Signer
  • account_id - The user AccountId in a Near network
  • new_account_pk - The new Ed25519PublicKey
  • permission - Granted permissions level for the new access key
pub fn delete_access_key<'a>( &'a self, signer: &'a Signer, account_id: &'a AccountId, public_key: Ed25519PublicKey, ) -> FunctionCall<'_>

Deletes an access key on the specified account

Arguments

pub fn function_call<'a>( &'a self, signer: &'a Signer, contract_id: &'a AccountId, method: &'static str, ) -> FunctionCallBuilder<'_>

Execute a transaction with a function call to the smart contract

Arguments

  • signer - Transaction Signer
  • contract_id - The AccountId where smart contract is located
  • method - Function that is declared in a smart contract (Arguments fir function call provided later in a [FunctionCallBuilder])
pub fn deploy_contract<'a>( &'a self, signer: &'a Signer, contract_id: &'a AccountId, wasm: Vec<u8>, ) -> FunctionCall<'_>

Deploys contract code to the chain

Arguments
  • signer - Transaction Signer
  • contract_id - The AccountId where smart contract is located
  • wasm - Actually a compiled code
pub fn create_account<'a>( &'a self, signer: &'a Signer, new_account_id: &'a AccountId, new_account_pk: Ed25519PublicKey, amount: Balance, ) -> FunctionCall<'_>

Creates account

Arguments
  • signer - Transaction Signer
  • new_account_id - The new AccountId
  • new_account_pk - The new Ed25519PublicKey
  • amount - Initial balance of that account, could be zero
pub fn delete_account<'a>( &'a self, signer: &'a Signer, account_id: &'a AccountId, beneficiary_acc_id: &'a AccountId, ) -> FunctionCall<'_>

Deletes account

Arguments
  • signer - Transaction Signer
  • account_id - The AccountId that we own and want to delete
  • beneficiary_acc_id - Where to return a founds from the deleted account
pub fn send<'a>( &'a self, signer: &'a Signer, receiver_id: &'a AccountId, deposit: Balance, ) -> FunctionCall<'_>

Sends Near tokens from one account to another.

Arguments
  • signer - The account ID of the sender and transaction Signer
  • receiver_id - The account ID of the receiver.
  • deposit - The amount of Near tokens to send.
Errors

Possible error conditions include insufficient funds, invalid account IDs, or other issues preventing the successful execution of the transaction.