pub struct NearClient { /* private fields */ }Expand description
Near RPC client
Implementations
Sourceimpl NearClient
impl NearClient
Sourcepub async fn block(&self, finality: Finality) -> Result<CryptoHash, Error>
pub async fn block(&self, finality: Finality) -> Result<CryptoHash, Error>
Queries network and returns block for given height or hash
Sourcepub async fn view<'a, T: DeserializeOwned>(
&'a self,
contract_id: &'a AccountId,
finality: Finality,
method: &'static str,
args: Option<Value>,
) -> Result<ViewOutput<T>, Error>
pub async fn view<'a, T: DeserializeOwned>( &'a self, contract_id: &'a AccountId, finality: Finality, method: &'static str, args: Option<Value>, ) -> Result<ViewOutput<T>, Error>
Sourcepub async fn view_access_key(
&self,
account_id: &AccountId,
public_key: &Ed25519PublicKey,
finality: Finality,
) -> Result<AccessKeyView, Error>
pub async fn view_access_key( &self, account_id: &AccountId, public_key: &Ed25519PublicKey, finality: Finality, ) -> Result<AccessKeyView, Error>
Returns information about a single access key for given account
Arguments
- account_id - The user
AccountIdin a Near network - public_key - The user
Ed25519PublicKeyin a Near network
Sourcepub async fn view_access_key_list(
&self,
account_id: &AccountId,
finality: Finality,
) -> Result<AccessKeyListView, Error>
pub async fn view_access_key_list( &self, account_id: &AccountId, finality: Finality, ) -> Result<AccessKeyListView, Error>
Returns list of all access keys for the given account
Arguments
- account_id - The user
AccountIdin a Near network
Sourcepub async fn view_contract_state(
&self,
account_id: &AccountId,
) -> Result<ViewStateResult, Error>
pub async fn view_contract_state( &self, account_id: &AccountId, ) -> Result<ViewStateResult, Error>
Returns information regarding contract state in a key-value sequence representation
Arguments
- account_id - The contract
AccountIdin a Near network
Sourcepub async fn network_status(&self) -> Result<StatusResponse, Error>
pub async fn network_status(&self) -> Result<StatusResponse, Error>
Returns general status of a given node (sync status, nearcore node version, protocol version, etc), and the current set of validators.
Sourcepub async fn view_transaction<'a>(
&'a self,
transaction_id: &'a CryptoHash,
signer: &'a Signer,
) -> Result<Output, Error>
pub async fn view_transaction<'a>( &'a self, transaction_id: &'a CryptoHash, signer: &'a Signer, ) -> Result<Output, Error>
Queries status of a transaction by hash, returning the final transaction result and details of all receipts.
Arguments
- transaction_id - Transaction
CryptoHash - signer -
Signerthat contain information regarding userKeypair
Return
If a transaction still processing will be returned an error Error::ViewTransaction,
in this case can try to execute view_transaction one more time, or a several times.
If an error differs from Error::ViewTransaction that something goes totally wrong and
you should stop to try executing view_transaction with the same arguments/signer
Sourcepub fn add_access_key<'a>(
&'a self,
signer: &'a Signer,
account_id: &'a AccountId,
new_account_pk: Ed25519PublicKey,
permission: AccessKeyPermission,
) -> FunctionCall<'_>
pub fn add_access_key<'a>( &'a self, signer: &'a Signer, account_id: &'a AccountId, new_account_pk: Ed25519PublicKey, permission: AccessKeyPermission, ) -> FunctionCall<'_>
Creates new access key on the specified account
Arguments
- signer - Transaction
Signer - account_id - The user
AccountIdin a Near network - new_account_pk - The new
Ed25519PublicKey - permission - Granted permissions level for the new access key
Sourcepub fn delete_access_key<'a>(
&'a self,
signer: &'a Signer,
account_id: &'a AccountId,
public_key: Ed25519PublicKey,
) -> FunctionCall<'_>
pub fn delete_access_key<'a>( &'a self, signer: &'a Signer, account_id: &'a AccountId, public_key: Ed25519PublicKey, ) -> FunctionCall<'_>
Deletes an access key on the specified account
Arguments
- signer - Transaction
Signer - account_id - The user
AccountIdin a Near network - public_key - The
Ed25519PublicKeyto be deleted from users access keys
Sourcepub fn function_call<'a>(
&'a self,
signer: &'a Signer,
contract_id: &'a AccountId,
method: &'static str,
) -> FunctionCallBuilder<'_>
pub fn function_call<'a>( &'a self, signer: &'a Signer, contract_id: &'a AccountId, method: &'static str, ) -> FunctionCallBuilder<'_>
Sourcepub fn deploy_contract<'a>(
&'a self,
signer: &'a Signer,
contract_id: &'a AccountId,
wasm: Vec<u8>,
) -> FunctionCall<'_>
pub fn deploy_contract<'a>( &'a self, signer: &'a Signer, contract_id: &'a AccountId, wasm: Vec<u8>, ) -> FunctionCall<'_>
Sourcepub fn create_account<'a>(
&'a self,
signer: &'a Signer,
new_account_id: &'a AccountId,
new_account_pk: Ed25519PublicKey,
amount: Balance,
) -> FunctionCall<'_>
pub fn create_account<'a>( &'a self, signer: &'a Signer, new_account_id: &'a AccountId, new_account_pk: Ed25519PublicKey, amount: Balance, ) -> FunctionCall<'_>
Creates account
Arguments
- signer - Transaction
Signer - new_account_id - The new
AccountId - new_account_pk - The new
Ed25519PublicKey - amount - Initial balance of that account, could be zero
Sourcepub fn delete_account<'a>(
&'a self,
signer: &'a Signer,
account_id: &'a AccountId,
beneficiary_acc_id: &'a AccountId,
) -> FunctionCall<'_>
pub fn delete_account<'a>( &'a self, signer: &'a Signer, account_id: &'a AccountId, beneficiary_acc_id: &'a AccountId, ) -> FunctionCall<'_>
Sourcepub fn send<'a>(
&'a self,
signer: &'a Signer,
receiver_id: &'a AccountId,
deposit: Balance,
) -> FunctionCall<'_>
pub fn send<'a>( &'a self, signer: &'a Signer, receiver_id: &'a AccountId, deposit: Balance, ) -> FunctionCall<'_>
Sends Near tokens from one account to another.
Arguments
signer- The account ID of the sender and transactionSignerreceiver_id- The account ID of the receiver.deposit- The amount of Near tokens to send.
Errors
Possible error conditions include insufficient funds, invalid account IDs, or other issues preventing the successful execution of the transaction.